summaryrefslogtreecommitdiffstats
path: root/kexi/core/kexidbshortcutfile.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/core/kexidbshortcutfile.cpp')
-rw-r--r--kexi/core/kexidbshortcutfile.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kexi/core/kexidbshortcutfile.cpp b/kexi/core/kexidbshortcutfile.cpp
index 01f0adb3..451eb66a 100644
--- a/kexi/core/kexidbshortcutfile.cpp
+++ b/kexi/core/kexidbshortcutfile.cpp
@@ -97,7 +97,7 @@ bool KexiDBShortcutFile::loadProjectData(KexiProjectData& data, TQString* _group
d->isDatabaseShortcut = false;
}
else {
//ERR: i18n("No valid "type" field specified for section \"%1\": unknown value \"%2\".").arg(group).arg(type)
return false;
}
@@ -194,9 +194,9 @@ bool KexiDBShortcutFile::saveProjectData(const KexiProjectData& data,
groupPrefix = "Database%1"; //do not i18n!
int number = 1;
- while (config.hasGroup(groupPrefix.arg(number))) //a new group key couldn't exist
+ while (config.hasGroup(groupPrefix.tqarg(number))) //a new group key couldn't exist
number++;
- groupKey = groupPrefix.arg(number);
+ groupKey = groupPrefix.tqarg(number);
}
if (_groupKey) //return this one (generated or found)
*_groupKey = groupKey;
@@ -97,7 +97,7 @@ bool KexiDBShortcutFile::loadProjectData(KexiProjectData& data, TQString* _group
}
else {
- //ERR: i18n("No valid "type" field specified for section \"%1\": unknown value \"%2\".").arg(group).arg(type)
+ //ERR: i18n("No valid "type" field specified for section \"%1\": unknown value \"%2\".").tqarg(group).tqarg(type)
return false;
}